==> v0.1.1.zip: hugo-academic-mirror/starters/portfolio/content/about/accomplishments.md <==
---
# An instance of the Accomplishments widget.
# Documentation: https://docs.hugoblox.com/page-builder/
widget: accomplishments

# This file represents a page section.
headless: true

# Order that this section appears on the page.
weight: 40

# Note: `&shy;` is used to add a 'soft' hyphen in a long heading.
title: 'Accomplish&shy;ments'
subtitle:

# Date format
#   Refer to https://docs.hugoblox.com/customization/#date-format
date_format: Jan 2006

# Accomplishments.
#   Add/remove as many `item` blocks below as you like.
#   `title`, `organization`, and `date_start` are the required parameters.
#   Leave other parameters empty if not required.
#   Begin multi-line descriptions with YAML's `|2-` multi-line prefix.
item:
  - certificate_url: https://www.coursera.org
    date_end: ''
    date_start: '2021-01-25'
    description: ''
    organization: Coursera
    organization_url: https://www.coursera.org
    title: Neural Networks and Deep Learning
    url: ''
  - certificate_url: https://www.edx.org
    date_end: ''
    date_start: '2021-01-01'
    description: Formulated informed blockchain models, hypotheses, and use cases.
    organization: edX
    organization_url: https://www.edx.org
    title: Blockchain Fundamentals
    url: https://www.edx.org/professional-certificate/uc-berkeleyx-blockchain-fundamentals
  - certificate_url: https://www.datacamp.com
    date_end: '2020-12-21'
    date_start: '2020-07-01'
    description: ''
    organization: DataCamp
    organization_url: https://www.datacamp.com
    title: 'Object-Oriented Programming in R'
    url: ''

design:
  columns: '1'
---

==> v1.0.0.zip: hugo-academic-mirror/starters/portfolio/content/about/accomplishments.md <==
---
# An instance of the Accomplishments widget.
# Documentation: https://wowchemy.com/docs/page-builder/
widget: accomplishments

# This file represents a page section.
headless: true

# Order that this section appears on the page.
weight: 40

# Note: `&shy;` is used to add a 'soft' hyphen in a long heading.
title: 'Accomplish&shy;ments'
subtitle:

# Date format
#   Refer to https://wowchemy.com/docs/customization/#date-format
date_format: Jan 2006

# Accomplishments.
#   Add/remove as many `item` blocks below as you like.
#   `title`, `organization`, and `date_start` are the required parameters.
#   Leave other parameters empty if not required.
#   Begin multi-line descriptions with YAML's `|2-` multi-line prefix.
item:
  - certificate_url: https://www.coursera.org
    date_end: ''
    date_start: '2021-01-25'
    description: ''
    organization: Coursera
    organization_url: https://www.coursera.org
    title: Neural Networks and Deep Learning
    url: ''
  - certificate_url: https://www.edx.org
    date_end: ''
    date_start: '2021-01-01'
    description: Formulated informed blockchain models, hypotheses, and use cases.
    organization: edX
    organization_url: https://www.edx.org
    title: Blockchain Fundamentals
    url: https://www.edx.org/professional-certificate/uc-berkeleyx-blockchain-fundamentals
  - certificate_url: https://www.datacamp.com
    date_end: '2020-12-21'
    date_start: '2020-07-01'
    description: ''
    organization: DataCamp
    organization_url: https://www.datacamp.com
    title: 'Object-Oriented Programming in R'
    url: ''

design:
  columns: '1'
---
